package it.danieleverducci.subitobeers.ui

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import com.squareup.picasso.Picasso
import it.danieleverducci.subitobeers.R
import it.danieleverducci.subitobeers.databinding.FragmentBeerDetailBinding
import it.danieleverducci.subitobeers.entities.Beer

/**
 * A simple beer detail fragment, with an image and some textual data
 */
class BeerDetailFragment(val beer: Beer) : Fragment() {

    lateinit var binding: FragmentBeerDetailBinding

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = FragmentBeerDetailBinding.inflate(
            LayoutInflater.from(container!!.context),
            container,
            false
        )

        // Populate view
        Picasso.get()
            .load(beer.imageUrl)
            .placeholder(R.drawable.ic_launcher_foreground)
            .error(R.drawable.ic_launcher_foreground)
            .into(binding.beerDetailPic)
        binding.beerDetailTitle.text = beer.name
        binding.beerDetailShortdesc.text = beer.tagline
        binding.beerDetailDesc.text = beer.description
        binding.beerDetailFirstbrewed.text = beer.firstBrewed

        return binding.root
    }

    override fun onStart() {
        super.onStart()
        requireActivity().actionBar?.setDisplayHomeAsUpEnabled(true);
    }

    override fun onStop() {
        super.onStop()
        requireActivity().actionBar?.setDisplayHomeAsUpEnabled(false);
    }
}